@@ -3,17 +3,26 @@
 所有协议适配器都必须继承自 `Adapter` 基类。
 """
 import os
-import asyncio
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Type, Union, Generic, Callable, Optional, Awaitable
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Type,
+    Union,
+    Generic,
+    Callable,
+    Optional,
+    Awaitable,
+    final,
+)
 
-from alicebot.config import ConfigModel
 from alicebot.log import error_or_exception
 from alicebot.typing import T_Event, T_Config
-from alicebot.utils import is_config_class, sync_func_wrapper
+from alicebot.utils import wrap_get_func, is_config_class
 
 if TYPE_CHECKING:
     from alicebot.bot import Bot
+    from alicebot.event import Event
 
 __all__ = ["Adapter"]
 
@@ -32,7 +41,7 @@ class Adapter(Generic[T_Event, T_Config], ABC):
 
     name: str
     bot: "Bot"
-    Config: Type[ConfigModel]
+    Config: Type[T_Config] = type(None)  # type: ignore
 
     def __init__(self, bot: "Bot"):
         if not hasattr(self, "name"):
@@ -41,13 +50,13 @@ class Adapter(Generic[T_Event, T_Config], ABC):
         self.handle_event = self.bot.handle_event
 
     @property
-    def config(self) -> Optional[T_Config]:
+    def config(self) -> T_Config:
         """适配器配置。"""
-        config_class: ConfigModel = getattr(self, "Config", None)
-        if is_config_class(config_class):
-            return getattr(self.bot.config.adapter, config_class.__config_name__, None)
-        return None
+        if is_config_class(self.Config):
+            return getattr(self.bot.config.adapter, self.Config.__config_name__, None)  # type: ignore
+        return None  # type: ignore
 
+    @final
     async def safe_run(self):
         """附带有异常处理地安全运行适配器。"""
         try:
@@ -63,7 +72,7 @@ class Adapter(Generic[T_Event, T_Config], ABC):
     async def run(self):
         """适配器运行方法，适配器开发者必须实现该方法。
 
-        适配器运行过程中保持保持运行，当此方法结束后，AliceBot 不会自动重新启动适配器。
+        适配器运行过程中保持保持运行，当此方法结束后， AliceBot 不会自动重新启动适配器。
         """
         raise NotImplementedError
 
@@ -82,13 +91,14 @@ class Adapter(Generic[T_Event, T_Config], ABC):
         """
         pass
 
-    async def send(self, *args, **kwargs):
+    async def send(self, *args: Any, **kwargs: Any):
         """发送消息，需要适配器开发者实现。"""
         raise NotImplementedError
 
+    @final
     async def get(
         self,
-        func: Optional[Callable[[T_Event], Union[bool, Awaitable[bool]]]] = None,
+        func: Optional[Callable[["Event"], Union[bool, Awaitable[bool]]]] = None,
         *,
         max_try_times: Optional[int] = None,
         timeout: Optional[Union[int, float]] = None,
@@ -112,18 +122,18 @@ class Adapter(Generic[T_Event, T_Config], ABC):
             GetEventTimeout: 超过最大事件数或超时。
         """
 
-        def func_wrapper(_func):
-            async def _wrapper(_event: T_Event):
+        def func_wrapper(
+            _func: Callable[["Event"], Awaitable[bool]]
+        ) -> Callable[["Event"], Awaitable[bool]]:
+            async def _wrapper(_event: "Event") -> bool:
                 if _event.adapter is not self:
                     return False
                 return await _func(_event)
 
             return _wrapper
 
-        if func is None:
-            func = sync_func_wrapper(lambda x: True)
-        elif not asyncio.iscoroutinefunction(func):
-            func = sync_func_wrapper(func)
-        func = func_wrapper(func)
-
-        return await self.bot.get(func, max_try_times=max_try_times, timeout=timeout)
+        return await self.bot.get(
+            func_wrapper(wrap_get_func(func)),
+            max_try_times=max_try_times,
+            timeout=timeout,
+        )  # type: ignore
