@@ -3,7 +3,7 @@
 事件类的基类。适配器开发者应实现此事件类基类的子类。
 """
 from abc import ABC
-from typing import Any, Generic, Optional
+from typing import Any, Generic, Optional, final
 
 from pydantic import BaseModel, PrivateAttr
 
@@ -24,7 +24,7 @@ class Event(ABC, BaseModel, Generic[T_Adapter]):
             警告：请勿手动更改此属性的值。
     """
 
-    adapter: Any
+    adapter: T_Adapter  # type: ignore
     # 这里的 adapter 类型定义只是为了 IDE 的类型检查工具能够正常工作，这个字段将永远不会被实际使用
     # IDE 对 BaseModel 实例化时的提示会将 BaseModel 视为 dataclasses，而忽略 __init__ 定义
     # 因此需要此定义防止类型提示出错
@@ -34,16 +34,14 @@ class Event(ABC, BaseModel, Generic[T_Adapter]):
 
     type: Optional[str]
 
-    _adapter: Optional[T_Adapter] = PrivateAttr()  # adapter 实际上放在这里
+    _adapter: T_Adapter = PrivateAttr()  # adapter 实际上放在这里
     __handled__: bool = PrivateAttr(default=False)
 
-    def __init__(self, **data):
-        if "adapter" in data:
-            self._adapter = data.pop("adapter")
-        else:
-            raise ValueError('"adapter" argument must be set')
+    def __init__(self, adapter: T_Adapter, **data: Any):
+        self._adapter = adapter
         super().__init__(**data)
 
+    @final
     @property
     def adapter(self) -> T_Adapter:
         """产生当前事件的适配器对象。"""
