@@ -3,29 +3,44 @@ import json
 import asyncio
 import inspect
 import os.path
-import pkgutil
 import importlib
 import traceback
 import dataclasses
 from abc import ABC
 from types import ModuleType
 from functools import partial
-from typing_extensions import ParamSpec
 from importlib.abc import MetaPathFinder
 from importlib.machinery import PathFinder
-from typing import Any, List, Type, Tuple, TypeVar, Callable, Iterable, Coroutine
+from typing_extensions import ParamSpec, TypeGuard
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    List,
+    Type,
+    Tuple,
+    Union,
+    TypeVar,
+    Callable,
+    Optional,
+    Sequence,
+    Awaitable,
+    Coroutine,
+)
 
 from alicebot.config import ConfigModel
 
+if TYPE_CHECKING:
+    from alicebot.event import Event
+
 __all__ = [
     "ModulePathFinder",
     "is_config_class",
     "get_classes_from_module",
     "get_classes_from_module_name",
-    "get_classes_from_dir",
     "DataclassEncoder",
     "samefile",
     "sync_func_wrapper",
+    "wrap_get_func",
 ]
 
 _T = TypeVar("_T")
@@ -38,13 +53,18 @@ class ModulePathFinder(MetaPathFinder):
 
     path: List[str] = []
 
-    def find_spec(self, fullname, path=None, target=None):
+    def find_spec(
+        self,
+        fullname: str,
+        path: Optional[Sequence[str]] = None,
+        target: Optional[ModuleType] = None,
+    ):
         if path is None:
             path = []
         return PathFinder.find_spec(fullname, self.path + list(path), target)
 
 
-def is_config_class(config_class: Any) -> bool:
+def is_config_class(config_class: Any) -> TypeGuard[Type[ConfigModel]]:
     """判断一个对象是否是配置类。
 
     Args:
@@ -118,34 +138,10 @@ def get_classes_from_module_name(
         raise ImportError(e, traceback.format_exc()) from e
 
 
-def get_classes_from_dir(
-    dirs: Iterable[str], super_class: Type[_T]
-) -> List[Tuple[Type[_T], ModuleType]]:
-    """从指定路径列表中的所有模块中查找指定类型的类，以 `_` 开头的插件不会被导入。路径可以是相对路径或绝对路径。
-
-    Args:
-        dirs: 储存模块的路径的列表。
-        super_class: 要查找的类的超类。
-
-    Returns:
-        返回由符合条件的类和模块组成的元组的列表。
-    """
-    classes: List[Tuple[Type[_T], ModuleType]] = []
-    for module_info in pkgutil.iter_modules(dirs):
-        if not module_info.name.startswith("_"):
-            try:
-                classes.extend(
-                    get_classes_from_module_name(module_info.name, super_class)
-                )
-            except ImportError:
-                continue
-    return classes
-
-
 class DataclassEncoder(json.JSONEncoder):
     """用于解析 MessageSegment 的 JSONEncoder 类。"""
 
-    def default(self, o):
+    def default(self, o: Any):
         if dataclasses.is_dataclass(o):
             return o.as_dict()
         return super().default(o)
@@ -192,3 +188,22 @@ def sync_func_wrapper(
             return func(*args, **kwargs)
 
     return _wrapper
+
+
+def wrap_get_func(
+    func: Optional[Callable[["Event"], Union[bool, Awaitable[bool]]]]
+) -> Callable[["Event"], Awaitable[bool]]:
+    """将 `get()` 函数接受的参数包装为一个异步函数。
+
+    Args:
+        func: `get()` 函数接受的参数。
+
+    Returns:
+        异步函数。
+    """
+    if func is None:
+        return sync_func_wrapper(lambda _: True)
+    elif not asyncio.iscoroutinefunction(func):
+        return sync_func_wrapper(func)  # type: ignore
+    else:
+        return func
